@@ -71,6 +71,9 @@ public class AllCrawlersTestSuite{
         testSuite.addTestSuite(WebDeTest.class);              
         testSuite.addTestSuite(XINGTest.class);
         testSuite.addTestSuite(YahooComTest.class);
+        testSuite.addTestSuite(GMXComTest.class);
+        testSuite.addTestSuite(TOnlineDETEst.class);
+        testSuite.addTestSuite(MSNTest.class);
         return testSuite;
     }
 }
